@@ -1,7 +1,7 @@
 /*
  * libopenraw - cameraids.h
  *
- * Copyright (C) 2012-2018 Hubert Figuière
+ * Copyright (C) 2012-2020 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -18,7 +18,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 /**
- * @brief the libopenraw public consts types
+ * @brief the libopenraw list of camera id.
  * @author Hubert Figuière <hub@figuiere.net>
  */
 
@@ -53,6 +53,10 @@ enum {
     OR_TYPEID_VENDOR_BLACKMAGIC = 15,
     OR_TYPEID_VENDOR_XIAOYI = 16,
     OR_TYPEID_VENDOR_APPLE = 17,
+    OR_TYPEID_VENDOR_SIGMA = 18,
+    OR_TYPEID_VENDOR_GOPRO = 19,
+    OR_TYPEID_VENDOR_HASSELBLAD = 20,
+    OR_TYPEID_VENDOR_ZEISS = 21,
 
     _OR_TYPEID_VENDOR_LAST
 };
@@ -75,8 +79,11 @@ enum {
     OR_TYPEID_CANON_REBEL_XT = OR_TYPEID_CANON_350D,
     OR_TYPEID_CANON_KISS_DIGITAL_N = OR_TYPEID_CANON_350D,
     OR_TYPEID_CANON_400D = 5,
+    OR_TYPEID_CANON_REBEL_XTI = OR_TYPEID_CANON_400D,
+    OR_TYPEID_CANON_KISS_DIGITAL_X = OR_TYPEID_CANON_400D,
     OR_TYPEID_CANON_450D = 6,
     OR_TYPEID_CANON_REBEL_XSI = OR_TYPEID_CANON_450D,
+    OR_TYPEID_CANON_KISS_X2 = OR_TYPEID_CANON_450D,
     OR_TYPEID_CANON_5D = 7,
     OR_TYPEID_CANON_1D = 8,
     OR_TYPEID_CANON_1DMKII = 9,
@@ -85,6 +92,7 @@ enum {
     OR_TYPEID_CANON_1DSMKII = 12,
     OR_TYPEID_CANON_1DSMKIII = 13,
     OR_TYPEID_CANON_300D = 14,
+    OR_TYPEID_CANON_DIGITAL_REBEL = OR_TYPEID_CANON_300D,
     OR_TYPEID_CANON_D30 = 15,
     OR_TYPEID_CANON_D60 = 16,
     OR_TYPEID_CANON_10D = 17,
@@ -107,8 +115,10 @@ enum {
     OR_TYPEID_CANON_5DMKII = 32,
     OR_TYPEID_CANON_550D = 33,
     OR_TYPEID_CANON_REBEL_T2I = OR_TYPEID_CANON_550D,
+    OR_TYPEID_CANON_KISS_X4 = OR_TYPEID_CANON_550D,
     OR_TYPEID_CANON_1000D = 34,
     OR_TYPEID_CANON_REBEL_XS = OR_TYPEID_CANON_1000D,
+    OR_TYPEID_CANON_KISS_F = OR_TYPEID_CANON_1000D,
     OR_TYPEID_CANON_G10 = 35,
     OR_TYPEID_CANON_50D = 36,
     OR_TYPEID_CANON_60D = 36,
@@ -117,8 +127,10 @@ enum {
     OR_TYPEID_CANON_S95 = 39,
     OR_TYPEID_CANON_600D = 40,
     OR_TYPEID_CANON_REBEL_T3I = OR_TYPEID_CANON_600D,
+    OR_TYPEID_CANON_KISS_X5 = OR_TYPEID_CANON_600D,
     OR_TYPEID_CANON_1100D = 41,
     OR_TYPEID_CANON_REBEL_T3 = OR_TYPEID_CANON_1100D,
+    OR_TYPEID_CANON_KISS_X50 = OR_TYPEID_CANON_1100D,
     OR_TYPEID_CANON_G1X = 42,
     OR_TYPEID_CANON_S100 = 43,
     OR_TYPEID_CANON_5DMKIII = 44,
@@ -126,6 +138,7 @@ enum {
     OR_TYPEID_CANON_60Da = 46,
     OR_TYPEID_CANON_650D = 47,
     OR_TYPEID_CANON_REBEL_T4I = OR_TYPEID_CANON_650D,
+    OR_TYPEID_CANON_KISS_X6I = OR_TYPEID_CANON_650D,
     OR_TYPEID_CANON_G15 = 48,
     OR_TYPEID_CANON_6D = 49,
     OR_TYPEID_CANON_EOS_M = 50,
@@ -133,8 +146,10 @@ enum {
     OR_TYPEID_CANON_S110 = 52,
     OR_TYPEID_CANON_100D = 53,
     OR_TYPEID_CANON_REBEL_SL1 = OR_TYPEID_CANON_100D,
+    OR_TYPEID_CANON_KISS_X7 = OR_TYPEID_CANON_100D,
     OR_TYPEID_CANON_700D = 54,
     OR_TYPEID_CANON_REBEL_T5I = OR_TYPEID_CANON_700D,
+    OR_TYPEID_CANON_KISS_X7I = OR_TYPEID_CANON_700D,
     OR_TYPEID_CANON_G16 = 55,
     OR_TYPEID_CANON_70D = 56,
     OR_TYPEID_CANON_7DMKII = 57,
@@ -142,8 +157,10 @@ enum {
     OR_TYPEID_CANON_G1XMKII = 59,
     OR_TYPEID_CANON_750D = 60,
     OR_TYPEID_CANON_REBEL_T6I = OR_TYPEID_CANON_750D,
+    OR_TYPEID_CANON_KISS_X8I = OR_TYPEID_CANON_750D,
     OR_TYPEID_CANON_760D = 61,
     OR_TYPEID_CANON_REBEL_T6S = OR_TYPEID_CANON_760D,
+    OR_TYPEID_CANON_8000D = OR_TYPEID_CANON_760D,
     OR_TYPEID_CANON_5DS_R = 62,
     OR_TYPEID_CANON_G3X = 63,
     OR_TYPEID_CANON_G9XMKII = 64,
@@ -153,15 +170,18 @@ enum {
     OR_TYPEID_CANON_G7XMKII = 68,
     OR_TYPEID_CANON_1300D = 69,
     OR_TYPEID_CANON_REBEL_T6 = OR_TYPEID_CANON_1300D,
+    OR_TYPEID_CANON_KISS_X80 = OR_TYPEID_CANON_1300D,
     OR_TYPEID_CANON_EOS_M3 = 70,
     OR_TYPEID_CANON_1DXMKII = 71,
     OR_TYPEID_CANON_80D = 72,
     OR_TYPEID_CANON_1200D = 73,
     OR_TYPEID_CANON_REBEL_T5 = OR_TYPEID_CANON_1200D,
+    OR_TYPEID_CANON_KISS_X70 = OR_TYPEID_CANON_1200D,
     OR_TYPEID_CANON_G9X = 74,
     OR_TYPEID_CANON_EOS_M10 = 75,
     OR_TYPEID_CANON_800D = 76,
     OR_TYPEID_CANON_REBEL_T7I = OR_TYPEID_CANON_800D,
+    OR_TYPEID_CANON_KISS_X9I = OR_TYPEID_CANON_800D,
     OR_TYPEID_CANON_77D = 77,
     OR_TYPEID_CANON_9000D = OR_TYPEID_CANON_77D,
     OR_TYPEID_CANON_EOS_M6 = 78,
@@ -169,8 +189,47 @@ enum {
     OR_TYPEID_CANON_6DMKII = 80,
     OR_TYPEID_CANON_200D = 81,
     OR_TYPEID_CANON_REBEL_SL2 = OR_TYPEID_CANON_200D,
+    OR_TYPEID_CANON_KISS_X9 = OR_TYPEID_CANON_200D,
     OR_TYPEID_CANON_G1XMKIII = 82,
     OR_TYPEID_CANON_5DS = 83,
+    OR_TYPEID_CANON_EOS_M50 = 84,
+    OR_TYPEID_CANON_KISS_M = OR_TYPEID_CANON_EOS_M50,
+    OR_TYPEID_CANON_SX1_IS = 85,
+    OR_TYPEID_CANON_S120 = 86,
+    OR_TYPEID_CANON_SX60_HS = 87,
+    OR_TYPEID_CANON_2000D = 88,
+    OR_TYPEID_CANON_REBEL_T7 = OR_TYPEID_CANON_2000D,
+    OR_TYPEID_CANON_KISS_X90 = OR_TYPEID_CANON_2000D,
+    OR_TYPEID_CANON_EOS_R = 89,
+    OR_TYPEID_CANON_3000D = 90,
+    OR_TYPEID_CANON_T100 = OR_TYPEID_CANON_3000D,
+    OR_TYPEID_CANON_4000D = OR_TYPEID_CANON_3000D,
+    OR_TYPEID_CANON_1DMKIIN = 91,
+    OR_TYPEID_CANON_SX70_HS = 92,
+    OR_TYPEID_CANON_EOS_RP = 93,
+    OR_TYPEID_CANON_250D = 94,
+    OR_TYPEID_CANON_REBEL_SL3 = OR_TYPEID_CANON_250D,
+    OR_TYPEID_CANON_KISS_X10 = OR_TYPEID_CANON_250D,
+    OR_TYPEID_CANON_G7XMKIII = 95,
+    OR_TYPEID_CANON_G5XMKII = 96,
+    OR_TYPEID_CANON_EOS_M6MKII = 97,
+    OR_TYPEID_CANON_90D = 98,
+    OR_TYPEID_CANON_EOS_M200 = 99,
+    OR_TYPEID_CANON_1DXMKIII = 100,
+    OR_TYPEID_CANON_EOS_R5 = 101,
+    OR_TYPEID_CANON_EOS_R6 = 102,
+    OR_TYPEID_CANON_S30 = 103,
+    OR_TYPEID_CANON_S40 = 104,
+    OR_TYPEID_CANON_S45 = 105,
+    OR_TYPEID_CANON_S50 = 106,
+    OR_TYPEID_CANON_S60 = 107,
+    OR_TYPEID_CANON_S70 = 108,
+    OR_TYPEID_CANON_S100V = 109,
+    OR_TYPEID_CANON_PRO70 = 110,
+    OR_TYPEID_CANON_PRO90 = 111,
+    OR_TYPEID_CANON_850D = 112,
+    OR_TYPEID_CANON_REBEL_T8I = OR_TYPEID_CANON_850D,
+    OR_TYPEID_CANON_KISS_X10I = OR_TYPEID_CANON_850D,
     _OR_TYPEID_CANON_LAST
 };
 
@@ -244,6 +303,21 @@ enum {
     OR_TYPEID_NIKON_COOLPIX_B700,
     OR_TYPEID_NIKON_COOLPIX_P330,
     OR_TYPEID_NIKON_COOLPIX_P340,
+    OR_TYPEID_NIKON_Z6,
+    OR_TYPEID_NIKON_Z7,
+    OR_TYPEID_NIKON_COOLPIX_P1000,
+    OR_TYPEID_NIKON_E8800,
+    OR_TYPEID_NIKON_D3500,
+    OR_TYPEID_NIKON_D2HS,
+    OR_TYPEID_NIKON_D2XS,
+    OR_TYPEID_NIKON_COOLPIX_A1000,
+    OR_TYPEID_NIKON_D780,
+    OR_TYPEID_NIKON_Z50,
+    OR_TYPEID_NIKON_COOLPIX_P950,
+    OR_TYPEID_NIKON_D6,
+    OR_TYPEID_NIKON_Z5,
+    OR_TYPEID_NIKON_Z6_2,
+    OR_TYPEID_NIKON_Z7_2,
     _OR_TYPEID_NIKON_LAST
 };
 
@@ -275,6 +349,29 @@ enum {
     OR_TYPEID_LEICA_VLUX_4 = 19,
     /* DNG */
     OR_TYPEID_LEICA_CL = 20,
+    /* RWL (Panasonic RAW) */
+    OR_TYPEID_LEICA_VLUX_TYP114 = 21,
+    OR_TYPEID_LEICA_CLUX = 22,
+    /* DNG */
+    OR_TYPEID_LEICA_M10P = 23,
+    OR_TYPEID_LEICA_M10D = 24,
+    OR_TYPEID_LEICA_TL2 = 25,
+    /* RWL */
+    OR_TYPEID_LEICA_DLUX_5 = 26,
+    OR_TYPEID_LEICA_DLUX_7 = 27,
+    OR_TYPEID_LEICA_C_TYP112 = 28,
+    OR_TYPEID_LEICA_VLUX_5 = 29,
+    /* DNG */
+    OR_TYPEID_LEICA_Q2 = 30,
+    OR_TYPEID_LEICA_SL2 = 31,
+    OR_TYPEID_LEICA_M10_MONOCHROM = 32,
+    OR_TYPEID_LEICA_M10R = 33,
+    OR_TYPEID_LEICA_M_MONOCHROM_TYP246 = 34,
+    /* RWL */
+    OR_TYPEID_LEICA_DLUX_4 = 35,
+    /* DNG */
+    OR_TYPEID_LEICA_SL2S = 36,
+    OR_TYPEID_LEICA_Q2_MONOCHROM = 37,
     _OR_TYPEID_LEICA_LAST
 };
 
@@ -325,6 +422,15 @@ enum {
     OR_TYPEID_PENTAX_QS1_PEF,
     OR_TYPEID_PENTAX_KP_PEF,
     OR_TYPEID_PENTAX_KP_DNG,
+    OR_TYPEID_PENTAX_K1_MKII_PEF,
+    OR_TYPEID_PENTAX_K1_MKII_DNG,
+    OR_TYPEID_PENTAX_K7_DNG,
+    OR_TYPEID_PENTAX_IST_DL2_PEF,
+    OR_TYPEID_PENTAX_K5_II_PEF,
+    OR_TYPEID_PENTAX_K5_II_DNG,
+    OR_TYPEID_PENTAX_K3_PEF,
+    OR_TYPEID_PENTAX_K3_II_PEF,
+    OR_TYPEID_PENTAX_K110D_PEF,
     _OR_TYPEID_PENTAX_LAST
 };
 
@@ -347,7 +453,8 @@ enum {
     OR_TYPEID_MINOLTA_DIMAGE7HI,
     OR_TYPEID_MINOLTA_MAXXUM_5D,
     OR_TYPEID_MINOLTA_MAXXUM_7D,
-    OR_TYPEID_MINOLTA_A200
+    OR_TYPEID_MINOLTA_A200,
+    _OR_TYPEID_MINOLTA_LAST
 };
 
 enum {
@@ -362,9 +469,9 @@ enum {
     OR_TYPEID_OLYMPUS_E500,
     OR_TYPEID_OLYMPUS_E510,
     OR_TYPEID_OLYMPUS_SP350,
-    OR_TYPEID_OLYMPUS_SP510,
-    OR_TYPEID_OLYMPUS_SP550,
-    OR_TYPEID_OLYMPUS_SP500,
+    OR_TYPEID_OLYMPUS_SP510UZ,
+    OR_TYPEID_OLYMPUS_SP550UZ,
+    OR_TYPEID_OLYMPUS_SP500UZ,
     OR_TYPEID_OLYMPUS_EP1,
     OR_TYPEID_OLYMPUS_E620,
     OR_TYPEID_OLYMPUS_EPL1,
@@ -393,13 +500,25 @@ enum {
     OR_TYPEID_OLYMPUS_XZ10,
     OR_TYPEID_OLYMPUS_TG4,
     OR_TYPEID_OLYMPUS_EPL9,
+    OR_TYPEID_OLYMPUS_STYLUS1_1S,
+    OR_TYPEID_OLYMPUS_EM10III,
+    OR_TYPEID_OLYMPUS_TG5,
+    OR_TYPEID_OLYMPUS_EM1X,
+    OR_TYPEID_OLYMPUS_TG6,
+    OR_TYPEID_OLYMPUS_EM5III,
+    OR_TYPEID_OLYMPUS_SP565UZ,
+    OR_TYPEID_OLYMPUS_EPL10,
+    OR_TYPEID_OLYMPUS_EM1III,
+    OR_TYPEID_OLYMPUS_EM10IV,
+
     _OR_TYPEID_OLYMPUS_LAST
 };
 
 enum {
     OR_TYPEID_SAMSUNG_UNKNOWN = 0,
     OR_TYPEID_SAMSUNG_GX10,
-    OR_TYPEID_SAMSUNG_PRO815
+    OR_TYPEID_SAMSUNG_PRO815,
+    _OR_TYPEID_SAMSUNG_LAST
 };
 
 enum {
@@ -408,60 +527,100 @@ enum {
     OR_TYPEID_RICOH_GXR = 2,
     OR_TYPEID_RICOH_GXR_A16 = 3,
     OR_TYPEID_RICOH_GR = 4, /* 2013 Ricoh GR-D */
+    OR_TYPEID_RICOH_GX200 = 5,
+    OR_TYPEID_PENTAX_645Z_PEF = 6,
+    OR_TYPEID_PENTAX_645Z_DNG = 7,
+    OR_TYPEID_RICOH_GRII = 8,
+    OR_TYPEID_RICOH_GRIII = 9,
     _OR_TYPEID_RICOH_LAST
 };
 
 enum {
     OR_TYPEID_SONY_UNKNOWN = 0,
-    OR_TYPEID_SONY_A100,
-    OR_TYPEID_SONY_A200,
-    OR_TYPEID_SONY_A700,
-    OR_TYPEID_SONY_A550,
-    OR_TYPEID_SONY_A380,
-    OR_TYPEID_SONY_A390,
-    OR_TYPEID_SONY_SLTA55,
-    OR_TYPEID_SONY_SLTA77,
-    OR_TYPEID_SONY_NEX3,
-    OR_TYPEID_SONY_NEX5,
-    OR_TYPEID_SONY_NEX5N,
-    OR_TYPEID_SONY_NEXC3,
-    OR_TYPEID_SONY_SLTA65,
-    OR_TYPEID_SONY_NEX7,
-    OR_TYPEID_SONY_A330,
-    OR_TYPEID_SONY_A350,
-    OR_TYPEID_SONY_A450,
-    OR_TYPEID_SONY_A580,
-    OR_TYPEID_SONY_A850,
-    OR_TYPEID_SONY_A900,
-    OR_TYPEID_SONY_SLTA35,
-    OR_TYPEID_SONY_SLTA33,
-    OR_TYPEID_SONY_A560,
-    OR_TYPEID_SONY_SLTA99,
-    OR_TYPEID_SONY_RX100,
-    OR_TYPEID_SONY_RX1,
-    OR_TYPEID_SONY_NEX6,
-    OR_TYPEID_SONY_SLTA57,
-    OR_TYPEID_SONY_NEXF3,
-    OR_TYPEID_SONY_NEX5R,
-    OR_TYPEID_SONY_RX100M2,
-    OR_TYPEID_SONY_RX1R,
-    OR_TYPEID_SONY_A7R,
-    OR_TYPEID_SONY_A7,
-    OR_TYPEID_SONY_A3000,
-    OR_TYPEID_SONY_NEX5T,
-    OR_TYPEID_SONY_SLTA58,
-    OR_TYPEID_SONY_A6000,
-    OR_TYPEID_SONY_RX100M3,
-    OR_TYPEID_SONY_A99M2,
-    OR_TYPEID_SONY_A7RM2,
-    OR_TYPEID_SONY_A6300,
-    OR_TYPEID_SONY_A6500,
-    OR_TYPEID_SONY_RX100M4,
-    OR_TYPEID_SONY_RX100M5,
-    OR_TYPEID_SONY_RX10,
-    OR_TYPEID_SONY_RX10M2,
-    OR_TYPEID_SONY_RX10M3,
-    OR_TYPEID_SONY_RX1RM2,
+    OR_TYPEID_SONY_A100 = 1,
+    OR_TYPEID_SONY_A200 = 2,
+    OR_TYPEID_SONY_A700 = 3,
+    OR_TYPEID_SONY_A550 = 4,
+    OR_TYPEID_SONY_A380 = 5,
+    OR_TYPEID_SONY_A390 = OR_TYPEID_SONY_A380,
+    OR_TYPEID_SONY_SLTA55 = 7,
+    OR_TYPEID_SONY_SLTA77 = 8,
+    OR_TYPEID_SONY_NEX3 = 9,
+    OR_TYPEID_SONY_NEX3N = 10,
+    OR_TYPEID_SONY_NEX5 = 11,
+    OR_TYPEID_SONY_NEX5N = 12,
+    OR_TYPEID_SONY_NEX5R = 13,
+    OR_TYPEID_SONY_NEX5T = 14,
+    OR_TYPEID_SONY_NEX6 = 15,
+    OR_TYPEID_SONY_NEX7 = 16,
+    OR_TYPEID_SONY_NEXC3 = 17,
+    OR_TYPEID_SONY_NEXF3 = 18,
+    OR_TYPEID_SONY_SLTA65 = 19,
+    OR_TYPEID_SONY_A330 = 21,
+    OR_TYPEID_SONY_A350 = 21,
+    OR_TYPEID_SONY_A450 = 22,
+    OR_TYPEID_SONY_A580 = 23,
+    OR_TYPEID_SONY_A850 = 24,
+    OR_TYPEID_SONY_A900 = 25,
+    OR_TYPEID_SONY_SLTA35 = 26,
+    OR_TYPEID_SONY_SLTA33 = 27,
+    OR_TYPEID_SONY_A560 = 28,
+    OR_TYPEID_SONY_SLTA99 = 29,
+    OR_TYPEID_SONY_RX100 = 30,
+    OR_TYPEID_SONY_RX100M2 = 31,
+    OR_TYPEID_SONY_RX100M3 = 32,
+    OR_TYPEID_SONY_RX100M4 = 33,
+    OR_TYPEID_SONY_RX100M5 = 34,
+    OR_TYPEID_SONY_RX100M6 = 35,
+    OR_TYPEID_SONY_RX1 = 36,
+    OR_TYPEID_SONY_RX1R = 37,
+    OR_TYPEID_SONY_RX10 = 38,
+    OR_TYPEID_SONY_RX10M2 = 39,
+    OR_TYPEID_SONY_RX10M3 = 40,
+    OR_TYPEID_SONY_RX1RM2 = 41,
+    OR_TYPEID_SONY_RX10M4 = 42,
+    OR_TYPEID_SONY_RX0 = 43,
+    OR_TYPEID_SONY_SLTA57 = 44,
+    OR_TYPEID_SONY_ILCE7 = 45,
+    OR_TYPEID_SONY_ILCE7M2 = 46,
+    OR_TYPEID_SONY_ILCE7M3 = 47,
+    OR_TYPEID_SONY_ILCE7R = 48,
+    OR_TYPEID_SONY_ILCE7RM2 = 49,
+    OR_TYPEID_SONY_ILCE7RM3 = 50,
+    OR_TYPEID_SONY_ILCE7S = 51,
+    OR_TYPEID_SONY_ILCE7SM2 = 52,
+    OR_TYPEID_SONY_ILCE9 = 53,
+    OR_TYPEID_SONY_ILCE3000 = 54,
+    OR_TYPEID_SONY_ILCE3500 = OR_TYPEID_SONY_ILCE3000,
+    OR_TYPEID_SONY_SLTA58 = 55,
+    OR_TYPEID_SONY_ILCE6000 = 56,
+    OR_TYPEID_SONY_ILCA99M2 = 57,
+    OR_TYPEID_SONY_ILCE6300 = 58,
+    OR_TYPEID_SONY_ILCE6500 = 59,
+    OR_TYPEID_SONY_ILCE5100 = 60,
+    OR_TYPEID_SONY_A230 = 61,
+    OR_TYPEID_SONY_A500 = 62,
+    OR_TYPEID_SONY_SLTA37 = 63,
+    OR_TYPEID_SONY_ILCA77M2 = 64,
+    OR_TYPEID_SONY_ILCA68 = 65,
+    OR_TYPEID_SONY_ILCE5000 = 66,
+    OR_TYPEID_SONY_A290 = 67,
+    OR_TYPEID_SONY_RX100M5A = 68,
+    OR_TYPEID_SONY_HX99 = 69,
+    OR_TYPEID_SONY_HX95 = OR_TYPEID_SONY_HX99,
+    OR_TYPEID_SONY_ILCE6400 = 70,
+    OR_TYPEID_SONY_RX0M2 = 71,
+    OR_TYPEID_SONY_ILCE7RM4 = 72,
+    OR_TYPEID_SONY_RX100M7 = 73,
+    OR_TYPEID_SONY_ILCE6100 = 74,
+    OR_TYPEID_SONY_ILCE6600 = 75,
+    OR_TYPEID_SONY_ILCE9M2 = 76,
+    OR_TYPEID_SONY_ZV1 = 77,
+    // SR2 file
+    OR_TYPEID_SONY_R1 = 78,
+    // ARW
+    OR_TYPEID_SONY_ILCE7SM3 = 79,
+    OR_TYPEID_SONY_ILCE7C = 80,
     _OR_TYPEID_SONY_LAST
 };
 
@@ -504,69 +663,117 @@ enum {
     OR_TYPEID_PANASONIC_LX10 = 34,
     OR_TYPEID_PANASONIC_LX15 = OR_TYPEID_PANASONIC_LX10,
     OR_TYPEID_PANASONIC_FZ2500 = 35,
+    OR_TYPEID_PANASONIC_FZ2000 = OR_TYPEID_PANASONIC_FZ2500,
     OR_TYPEID_PANASONIC_GX8 = 36,
     OR_TYPEID_PANASONIC_ZS100 = 37,
+    OR_TYPEID_PANASONIC_TX1 = OR_TYPEID_PANASONIC_ZS100,
+    OR_TYPEID_PANASONIC_TZ100 = OR_TYPEID_PANASONIC_ZS100,
+    OR_TYPEID_PANASONIC_TZ110 = OR_TYPEID_PANASONIC_ZS100,
     OR_TYPEID_PANASONIC_GX80 = 38,
     OR_TYPEID_PANASONIC_GX85 = OR_TYPEID_PANASONIC_GX80,
     OR_TYPEID_PANASONIC_GH5 = 39,
     OR_TYPEID_PANASONIC_GX850 = 40,
-    OR_TYPEID_PANASONIC_FZ82 = 41,
+    OR_TYPEID_PANASONIC_FZ80 = 41,
+    OR_TYPEID_PANASONIC_FZ82 = OR_TYPEID_PANASONIC_FZ80,
     OR_TYPEID_PANASONIC_FZ330 = 42,
     OR_TYPEID_PANASONIC_TZ70 = 43,
-    OR_TYPEID_PANASONIC_TZ80 = 44,
-    OR_TYPEID_PANASONIC_TZ100 = 45,
+    OR_TYPEID_PANASONIC_ZS60 = 44,
+    OR_TYPEID_PANASONIC_TZ80 = OR_TYPEID_PANASONIC_ZS60,
+
     OR_TYPEID_PANASONIC_GF7 = 46,
     OR_TYPEID_PANASONIC_CM1 = 47,
     OR_TYPEID_PANASONIC_GX9 = 48,
     OR_TYPEID_PANASONIC_GX800 = 49,
-    OR_TYPEID_PANASONIC_TZ202 = 50,
-    OR_TYPEID_PANASONIC_TZ110 = 51,
+
     OR_TYPEID_PANASONIC_G9 = 52,
+    OR_TYPEID_PANASONIC_DC_FZ45 = 53, // Not the DMC FZ45
+    OR_TYPEID_PANASONIC_GH5S = 54,
+    OR_TYPEID_PANASONIC_LX1 = 55,
+    OR_TYPEID_PANASONIC_FZ150 = 56,
+    OR_TYPEID_PANASONIC_FZ35 = 57,
+    OR_TYPEID_PANASONIC_ZS200 = 58,
+    OR_TYPEID_PANASONIC_TX2 = OR_TYPEID_PANASONIC_ZS200,
+    OR_TYPEID_PANASONIC_TZ202 = OR_TYPEID_PANASONIC_ZS200,
+    OR_TYPEID_PANASONIC_GX7MK2 = 59,
+    OR_TYPEID_PANASONIC_LX100M2 = 60,
+    OR_TYPEID_PANASONIC_DMC_FZ40 = 61,
+    OR_TYPEID_PANASONIC_DMC_FZ45 = OR_TYPEID_PANASONIC_DMC_FZ40, // Not the DC FZ45
+    OR_TYPEID_PANASONIC_DC_S1 = 62,
+    OR_TYPEID_PANASONIC_DC_S1R = 63,
+    OR_TYPEID_PANASONIC_DC_G95 = 64,
+    OR_TYPEID_PANASONIC_DMC_FZ1000 = 65,
+    OR_TYPEID_PANASONIC_DC_FZ1000M2 = 66,
+    OR_TYPEID_PANASONIC_DC_ZS80 = 67,
+    OR_TYPEID_PANASONIC_DC_TZ95 = OR_TYPEID_PANASONIC_DC_ZS80,
+    OR_TYPEID_PANASONIC_GF10 = 68,
+    OR_TYPEID_PANASONIC_GX880 = OR_TYPEID_PANASONIC_GF10,
+    OR_TYPEID_PANASONIC_DC_G99 = 69,
+    OR_TYPEID_PANASONIC_DC_G91 = OR_TYPEID_PANASONIC_DC_G99,
+    OR_TYPEID_PANASONIC_DC_S1H = 70,
+    OR_TYPEID_PANASONIC_DC_G100 = 71,
+    OR_TYPEID_PANASONIC_DC_S5 = 72,
     _OR_TYPEID_PANASONIC_LAST
 };
 
 enum {
     OR_TYPEID_FUJIFILM_UNKNOWN = 0,
-    OR_TYPEID_FUJIFILM_X100 = 1,
-    OR_TYPEID_FUJIFILM_F700 = 2,
-    OR_TYPEID_FUJIFILM_E900 = 3,
-    OR_TYPEID_FUJIFILM_S2PRO = 4,
-    OR_TYPEID_FUJIFILM_S3PRO = 5,
-    OR_TYPEID_FUJIFILM_S5PRO = 6,
-    OR_TYPEID_FUJIFILM_F810 = 7,
+    OR_TYPEID_FUJIFILM_F700 = 1,
+    OR_TYPEID_FUJIFILM_E900 = 2,
+    OR_TYPEID_FUJIFILM_S2PRO = 3,
+    OR_TYPEID_FUJIFILM_S3PRO = 4,
+    OR_TYPEID_FUJIFILM_S5PRO = 5,
+    OR_TYPEID_FUJIFILM_F810 = 6,
+    OR_TYPEID_FUJIFILM_S5000 = 7,
     OR_TYPEID_FUJIFILM_S5600 = 8,
     OR_TYPEID_FUJIFILM_S9500 = 9,
     OR_TYPEID_FUJIFILM_S6500FD = 10,
     OR_TYPEID_FUJIFILM_HS10 = 11,
-    OR_TYPEID_FUJIFILM_X10 = 12,
-    OR_TYPEID_FUJIFILM_XPRO1 = 13,
-    OR_TYPEID_FUJIFILM_XS1 = 14,
-    OR_TYPEID_FUJIFILM_S200EXR = 15,
-    OR_TYPEID_FUJIFILM_XE1 = 16,
-    OR_TYPEID_FUJIFILM_XF1 = 17,
-    OR_TYPEID_FUJIFILM_X100S = 18,
+    OR_TYPEID_FUJIFILM_HS30EXR = 12,
+    OR_TYPEID_FUJIFILM_HS33EXR = OR_TYPEID_FUJIFILM_HS30EXR,
+    OR_TYPEID_FUJIFILM_S200EXR = 13,
+    OR_TYPEID_FUJIFILM_X100 = 14,
+    OR_TYPEID_FUJIFILM_X100S = 15,
+    OR_TYPEID_FUJIFILM_X100T = 16,
+    OR_TYPEID_FUJIFILM_X100F = 17,
+    OR_TYPEID_FUJIFILM_X10 = 18,
     OR_TYPEID_FUJIFILM_X20 = 19,
-    OR_TYPEID_FUJIFILM_XM1 = 20,
-    OR_TYPEID_FUJIFILM_XE2 = 21,
-    OR_TYPEID_FUJIFILM_XT1 = 22,
-    OR_TYPEID_FUJIFILM_X30 = 23,
-    OR_TYPEID_FUJIFILM_XT10 = 24,
-    OR_TYPEID_FUJIFILM_X100T = 25,
-    OR_TYPEID_FUJIFILM_XA1 = 26,
-    OR_TYPEID_FUJIFILM_XQ1 = 27,
-    OR_TYPEID_FUJIFILM_GFX50S = 28,
-    OR_TYPEID_FUJIFILM_XT2 = 29,
-    OR_TYPEID_FUJIFILM_XE2S = 30,
-    OR_TYPEID_FUJIFILM_X70 = 31,
-    OR_TYPEID_FUJIFILM_XA2 = 32,
-    OR_TYPEID_FUJIFILM_XA3 = 33,
-    OR_TYPEID_FUJIFILM_XPRO2 = 34,
-    OR_TYPEID_FUJIFILM_X100F = 35,
-    OR_TYPEID_FUJIFILM_XT20 = 36,
-    OR_TYPEID_FUJIFILM_XE3 = 37,
-    OR_TYPEID_FUJIFILM_XH1 = 38,
-    OR_TYPEID_FUJIFILM_XA5 = 39,
-    OR_TYPEID_FUJIFILM_XQ2 = 40,
+    OR_TYPEID_FUJIFILM_X30 = 20,
+    OR_TYPEID_FUJIFILM_X70 = 21,
+    OR_TYPEID_FUJIFILM_XPRO1 = 22,
+    OR_TYPEID_FUJIFILM_XPRO2 = 23,
+    OR_TYPEID_FUJIFILM_XS1 = 24,
+    OR_TYPEID_FUJIFILM_XE1 = 25,
+    OR_TYPEID_FUJIFILM_XE2 = 26,
+    OR_TYPEID_FUJIFILM_XE2S = 27,
+    OR_TYPEID_FUJIFILM_XE3 = 28,
+    OR_TYPEID_FUJIFILM_XF1 = 29,
+    OR_TYPEID_FUJIFILM_XM1 = 30,
+    OR_TYPEID_FUJIFILM_XT1 = 31,
+    OR_TYPEID_FUJIFILM_XT10 = 32,
+    OR_TYPEID_FUJIFILM_XT100 = 33,
+    OR_TYPEID_FUJIFILM_XT2 = 34,
+    OR_TYPEID_FUJIFILM_XT20 = 35,
+    OR_TYPEID_FUJIFILM_XT3 = 36,
+    OR_TYPEID_FUJIFILM_XA1 = 37,
+    OR_TYPEID_FUJIFILM_XA2 = 38,
+    OR_TYPEID_FUJIFILM_XA3 = 39,
+    OR_TYPEID_FUJIFILM_XA5 = 40,
+    OR_TYPEID_FUJIFILM_XQ1 = 41,
+    OR_TYPEID_FUJIFILM_XQ2 = 42,
+    OR_TYPEID_FUJIFILM_XH1 = 43,
+    OR_TYPEID_FUJIFILM_GFX50S = 44,
+    OR_TYPEID_FUJIFILM_GFX50R = 45,
+    OR_TYPEID_FUJIFILM_XF10 = 46,
+    OR_TYPEID_FUJIFILM_XT30 = 47,
+    OR_TYPEID_FUJIFILM_GFX100 = 48,
+    OR_TYPEID_FUJIFILM_XA7 = 49,
+    OR_TYPEID_FUJIFILM_XPRO3 = 50,
+    OR_TYPEID_FUJIFILM_XT200 = 51,
+    OR_TYPEID_FUJIFILM_X100V = 52,
+    OR_TYPEID_FUJIFILM_XT4 = 53,
+    OR_TYPEID_FUJIFILM_F550EXR = 54,
+    OR_TYPEID_FUJIFILM_S100FS = 55,
+    OR_TYPEID_FUJIFILM_XS10 = 56,
     _OR_TYPEID_FUJIFILM_LAST
 };
 
@@ -579,6 +786,8 @@ enum {
 enum {
     OR_TYPEID_XIAOYI_UNKNOWN = 0,
     OR_TYPEID_XIAOYI_M1 = 1,
+    OR_TYPEID_XIAOYI_YDXJ_2 = 2,
+    OR_TYPEID_XIAOYI_YIAC_3 = 3,
     _OR_TYPEID_XIAOYI_LAST
 };
 
@@ -586,9 +795,43 @@ enum {
     OR_TYPEID_APPLE_UNKNOWN = 0,
     OR_TYPEID_APPLE_IPHONE_6SPLUS = 1,
     OR_TYPEID_APPLE_IPHONE_7PLUS = 2,
+    OR_TYPEID_APPLE_IPHONE_SE = 3,
+    OR_TYPEID_APPLE_IPHONE_8 = 4,
+    OR_TYPEID_APPLE_IPHONE_XS = 5,
     _OR_TYPEID_APPLE_LAST
 };
 
+enum {
+    OR_TYPEID_SIGMA_UNKNOWN = 0,
+    OR_TYPEID_SIGMA_FP = 1,
+    _OR_TYPEID_SIGMA_LAST
+};
+
+enum {
+    OR_TYPEID_GOPRO_UNKNOWN = 0,
+    OR_TYPEID_GOPRO_HERO5_BLACK = 1,
+    OR_TYPEID_GOPRO_HERO6_BLACK = 2,
+    OR_TYPEID_GOPRO_HERO7_BLACK = 3,
+    OR_TYPEID_GOPRO_HERO8_BLACK = 4,
+
+    _OR_TYPEID_GOPRO_LAST
+};
+
+enum {
+    OR_TYPEID_HASSELBLAD_UNKNOWN = 0,
+    OR_TYPEID_HASSELBLAD_LUNAR = 1,
+    OR_TYPEID_HASSELBLAD_L1D_20C = 2,
+
+    _OR_TYPEID_HASSELBLAD_LAST
+};
+
+enum {
+    OR_TYPEID_ZEISS_UNKNOWN = 0,
+    OR_TYPEID_ZEISS_ZX1 = 1,
+
+    _OR_TYPEID_ZEISS_LAST
+};
+
 #ifdef __cplusplus
 }
 #endif
